@@ -72,7 +72,7 @@ theme_brooklyn99 <- function(
           legend.text = element_text(family = legend.font, size = legend.text.size, color = legend.text.color),
           legend.title = element_text(family = legend.font, size = legend.title.size, color = legend.title.color),
           legend.position = legend.position,
-          legend.key = element_rect(colour = "black", linetype = "solid", size = 1.1),
+          legend.key = element_rect(colour = "black", linetype = "solid", linewidth = 1.1),
           legend.background = element_rect(color = "black", fill = "#0053CD", linetype = "solid")
     )
 
@@ -81,9 +81,9 @@ theme_brooklyn99 <- function(
                                  axis.ticks.x = element_blank(),
                                  axis.ticks.y = element_blank())
   } else {
-    pontiacBandit <- pontiacBandit + theme(axis.ticks = element_line(size = 0.15, color = "white"),
-                                 axis.ticks.x = element_line(size = 0.15, color = "white"),
-                                 axis.ticks.y = element_line(size = 0.15, color = "white"),
+    pontiacBandit <- pontiacBandit + theme(axis.ticks = element_line(linewidth = 0.15, color = "white"),
+                                 axis.ticks.x = element_line(linewidth = 0.15, color = "white"),
+                                 axis.ticks.y = element_line(linewidth = 0.15, color = "white"),
                                  axis.ticks.length = grid::unit(4, "pt"))
   }
 }
