@@ -81,9 +81,9 @@ theme_simpsons <- function(
                                axis.ticks.x = element_blank(),
                                axis.ticks.y = element_blank())
   } else {
-    simpsons <- simpsons + theme(axis.ticks = element_line(size = 0.15, color = "white"),
-                               axis.ticks.x = element_line(size = 0.15, color = "white"),
-                               axis.ticks.y = element_line(size = 0.15, color = "white"),
+    simpsons <- simpsons + theme(axis.ticks = element_line(linewidth = 0.15, color = "white"),
+                               axis.ticks.x = element_line(linewidth = 0.15, color = "white"),
+                               axis.ticks.y = element_line(linewidth = 0.15, color = "white"),
                                axis.ticks.length = grid::unit(4, "pt"))
   }
 }
