@@ -79,9 +79,9 @@ theme_spongeBob <- function(
                                axis.ticks.x = element_blank(),
                                axis.ticks.y = element_blank())
   } else {
-    bobspog <- bobspog + theme(axis.ticks = element_line(size = 0.15, color = "white"),
-                               axis.ticks.x = element_line(size = 0.15, color = "white"),
-                               axis.ticks.y = element_line(size = 0.15, color = "white"),
+    bobspog <- bobspog + theme(axis.ticks = element_line(linewidth = 0.15, color = "white"),
+                               axis.ticks.x = element_line(linewidth = 0.15, color = "white"),
+                               axis.ticks.y = element_line(linewidth = 0.15, color = "white"),
                                axis.ticks.length = grid::unit(4, "pt"))
   }
 }
