@@ -72,9 +72,9 @@ theme_theLastAirbender <- function(
                                  axis.ticks.x = element_blank(),
                                  axis.ticks.y = element_blank())
   } else {
-    airbender <- airbender + theme(axis.ticks = element_line(size = 0.15, color = "white"),
-                                 axis.ticks.x = element_line(size = 0.15, color = "white"),
-                                 axis.ticks.y = element_line(size = 0.15, color = "white"),
+    airbender <- airbender + theme(axis.ticks = element_line(linewidth = 0.15, color = "white"),
+                                 axis.ticks.x = element_line(linewidth = 0.15, color = "white"),
+                                 axis.ticks.y = element_line(linewidth = 0.15, color = "white"),
                                  axis.ticks.length = grid::unit(4, "pt"))
   }
 }
@@ -162,9 +162,9 @@ theme_avatar <- function(
                                    axis.ticks.x = element_blank(),
                                    axis.ticks.y = element_blank())
   } else {
-    airbender <- airbender + theme(axis.ticks = element_line(size = 0.15, color = "white"),
-                                   axis.ticks.x = element_line(size = 0.15, color = "white"),
-                                   axis.ticks.y = element_line(size = 0.15, color = "white"),
+    airbender <- airbender + theme(axis.ticks = element_line(linewidth = 0.15, color = "white"),
+                                   axis.ticks.x = element_line(linewidth = 0.15, color = "white"),
+                                   axis.ticks.y = element_line(linewidth = 0.15, color = "white"),
                                    axis.ticks.length = grid::unit(4, "pt"))
   }
 }
